<?php
/**
 * Theme Block editor
 *
 * @see
 * https://developer.wordpress.org/block-editor/developers/themes/theme-support/
 *
 * @since   2.0.0
 * @version 1.0.0
 */

add_action(
	'after_setup_theme',
	function () {
		// Load optional core block style.
		// Core block optional syle is wp-includes/css/dist/block-library/style.css.
		add_theme_support( 'wp-block-styles' );

		// Support Wide Alignments and Floats.
		// Kanagata support only :mage alignment.
		// To be specific, Support alignfull, alignwide, alignleft, alignright.
		add_theme_support( 'align-wide' );

		// No support Color Pallettes.
		// No support Block Gradient Presets.
		// No support Block Font Sizes.

		// Support custom line heights
		add_theme_support( 'custom-line-height' );
		// Support custom spacing. For Example, Custom spaceing is ussed by Cover block.
		add_theme_support( 'experimental-custom-spacing' );
		// Support Responsive embedded content.
		add_theme_support( 'responsive-embeds' );
		// Support Responsive embedded content.
		add_theme_support( 'responsive-embeds' );
		// Support Spacing control.
		add_theme_support( 'custom-spacing' );

		// NO support Experimental — Link color control
	},
	11
);

/*
 * Enqueue kanagata block css for the editor and front end.
 * This css are loaded in both the editor and the front end.
 */
add_action(
	'enqueue_block_assets',
	function () {
		wp_enqueue_style( 'block', get_template_directory_uri() . '/block.css' );
	}
);

/**
 * Enqueue kanagata block editor css.
 * This css are only loaded in the editor.
 */
add_action(
	'enqueue_block_editor_assets',
	function () {
		wp_enqueue_style( 'block-editor', get_template_directory_uri() . '/block-editor.css' );
		if ( 'bottom' === get_theme_mod( 'sidebar_layout', 'right' ) ) {
			wp_enqueue_style( 'block-editor-bottom', get_template_directory_uri() . '/block-editor.css' );
		}
	}
);
