<?php
/**
 * Get style that sets at Customizer API
 *
 * @return string style that set customizer api. no style return empty string.
 */
function kanagata_generate_customize_style() {
	$style = '';

	/*
	 * Jumbotron
	 */
	if ( '1' === get_theme_mod( 'jumbotron_background_gradient_enable', '' ) ) {
		$style .= sprintf(
			'.jumbotron {background: linear-gradient(%s, %s);}',
			kanagata_sanitize_color( get_theme_mod( 'jumbotron_background_gradient_start', '#000000' ) ),
			kanagata_sanitize_color( get_theme_mod( 'jumbotron_background_gradient_end', '#555555' ) )
		);

	} else {
		$style .= sprintf( '.jumbotron {background-color: %s;}', kanagata_sanitize_color( get_theme_mod( 'jumbotron_background_color', '#ffffff' ) ) );
	}

	if ( ! empty( get_theme_mod( 'jumbotron_background_image' ) ) ) {
		$style .= sprintf( ".jumbotron {background: url('%s') center center/cover no-repeat;}", esc_url_raw( get_theme_mod( 'jumbotron_background_image' ) ) );
	}
	$style .= sprintf( '.jumbotron-inner p {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'jumbotron_text_color', '#333333' ) ) );
	$style .= sprintf( '.jumbotron-inner p {font-size: %s;}', sanitize_text_field( get_theme_mod( 'jumbotron_text_size', '48px' ) ) );
	if ( 1 == (int) get_theme_mod( 'jumbotron_text_shadow', 0 ) ) {
		$style .= sprintf( '.jumbotron-inner p {text-shadow: %s;}', '1px 1px 1px #f5f5f5;' );
	}

	/*
	* link
	*/
	// Color.
	$style .= sprintf( 'a {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'link_a_color', '#337ab7' ) ) );
	$style .= sprintf( 'a:link {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'link_a_color', '#23527c' ) ) );
	$style .= sprintf( 'a:active {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'link_a_active_color', '#337ab7' ) ) );
	$style .= sprintf( 'a:visited {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'link_a_visited_color', '#337ab7' ) ) );
	$style .= sprintf( 'a:hover {color: %s;}', kanagata_sanitize_color( get_theme_mod( 'link_a_hover_color', '#23527c' ) ) );
	// Underline.
	$style .= sprintf( 'a {text-decoration: %s;}', kanagata_sanitize_color( get_theme_mod( 'text_decoration', 'underline' ) ) );

	/*
	* Background color.
	*/
	// Global menu. mobile and pc.
	$style .= sprintf(
		'.menu-global-container {background-color: %s;}',
		kanagata_sanitize_color( get_theme_mod( 'menu-global-background_color', '#ffffff' ) )
	);
	// Global dropdown menu.
	$style .= sprintf( '.menu-global .sub-menu li {background-color: %s;}', kanagata_sanitize_color( get_theme_mod( 'menu_global_dropdown', '#ffffff' ) ) );
	// Extra menu. mobile and pc.
	$style .= sprintf(
		'.menu-extra {background-color: %s;}',
		kanagata_sanitize_color( get_theme_mod( 'menu-extra-background_color', '#ffffff' ) )
	);
	// Extra dropdown menu.
	$style .= sprintf( '.menu-extra .sub-menu {background-color: %s;}', kanagata_sanitize_color( get_theme_mod( 'menu_extra_dropdown', '#ffffff' ) ) );
	$style .= sprintf( '#sidebar {background-color: %s;}', kanagata_sanitize_color( get_theme_mod( 'sidebar_background_color', '#ffffff' ) ) );
	// Pager
	$color  = sanitize_text_field( get_theme_mod( 'pager_background_color', '#ffffff' ) );
	$style .= sprintf( '.pager .current {background-color: %s;}', $color );
	$style .= sprintf( '.pager .page-numbers:hover  {background-color: %s;}', $color );

	/*
	* Sidebar
	*/
	$style .= sprintf( '#sidebar {background-color: %s;}', kanagata_sanitize_color( get_theme_mod( 'sidebar_background_color', '#ffffff' ) ) );

	/*
	* Size
	* return string 1 if checkbox is checked.
	* return string "" if checkbox is not checked.
	*/
	// Singular title. Singular title is single post title, page title, archive tittle(not posts title in archive).
	$size   = sanitize_text_field( get_theme_mod( 'singular_title', '30px' ) );
	$enable = get_theme_mod( 'singular_title_enable', '' );
	if ( '1' === $enable ) {
		$style .= sprintf( '.single-title, .page-title, .category-title {font-size: %s !important;}', $size );
	}
	$size   = sanitize_text_field( get_theme_mod( 'singular_title_margin_top', '0' ) );
	$enable = get_theme_mod( 'singular_title_margin_top_enable', '' );
	if ( '1' === $enable ) {
		$style .= sprintf( '.single-title, .page-title, .category-title {margin-top: %s !important;}', $size );
	}
	$size   = sanitize_text_field( get_theme_mod( 'singular_title_margin_bottom', '32px' ) );
	$enable = get_theme_mod( 'singular_title_margin_bottom_enable', '' );
	if ( '1' === $enable ) {
		$style .= sprintf( '.single-title, .page-title, .category-title {margin-bottom: %s !important;}', $size );
	}
	// Post title.
	$size   = sanitize_text_field( get_theme_mod( 'post_title', '26px' ) );
	$enable = get_theme_mod( 'post_title_enable', '' );
	if ( '1' === $enable ) {
		$style .= sprintf( '.post-title {font-size: %s !important;}', $size );
	}
	$size   = sanitize_text_field( get_theme_mod( 'post_title_margin_top' ) );
	$enable = get_theme_mod( 'post_title_margin_top_enable' );
	if ( '1' === $enable ) {
		$style .= sprintf( '.post-title {margin-top: %s !important;}', $size );
	}

	$size   = sanitize_text_field( get_theme_mod( 'post_title_margin_bottom', '32px' ) );
	$enable = get_theme_mod( 'post_title_margin_bottom_enable' );

	if ( '1' === $enable ) {
		$style .= sprintf( '.post-title {margin-bottom: %s !important;}', $size );
	}

	return $style;
}

add_action(
	'wp_head',
	function () {
		?>
	<style type="text/css">
		<?php echo kanagata_generate_customize_style(); ?> 
	</style> 
		<?php
	}
);
