<?php
/**
 * Custom functions for Theme Customization(for kanagata-customize.php)
 *
 * @subpackage kanagata
 * @since      1.3.0
 * @version    1.3.0
 */

/**
 * Get Sidebar layout
 *
 * @return boolean|string false left, right
 * @since  1.3.0
 */
function kanagata_get_sidebar_layout() {
	// Check theme_mod first, then check (theme)option. Default is right.
	$is_layout = kanagata_is_sidebar_layout( get_theme_mod( 'sidebar_layout' ) );
	if ( $is_layout ) {
		return kanagata_sanitize_sidebar_layout( get_theme_mod( 'sidebar_layout' ) );
	}
	$is_layout = kanagata_is_sidebar_layout( kanagata_get_theme_option_value( 'layout' ) );
	if ( $is_layout ) {
		return kanagata_sanitize_sidebar_layout( kanagata_get_theme_option_value( 'layout' ) );
	}

	return 'right';
}

/**
 * Get css class for layout
 *
 * @param  string $target element class (main or side).
 * @return string class name for layout.
 */
function kanagata_get_layout_class( $target ) {
	 $layout = kanagata_get_sidebar_layout();
	$data    = array();
	if ( 'left' === $layout ) {
		$data['main'] = 'col-md-8 pull-right';
		$data['side'] = 'col-md-4 pull-left';
	} elseif ( 'right' === $layout ) {
		$data['main'] = 'col-md-8 pull-left';
		$data['side'] = 'col-md-4 pull-right';
	} else {
		$data['main'] = 'col-md-12';
		$data['side'] = 'col-md-12';
	}
	if ( 'main' === $target ) {
		return $data['main'];
	}
	if ( 'side' === $target ) {
		return $data['side'];
	}

	return '';
}

/**
 * Specific category post display on top page
 *
 * @returkanagata_generate_customize_styleformation.
 */
function kanagata_get_specific_category() {
	 $data                          = array();
	$data['specific_category_name'] = sanitize_text_field( get_theme_mod( 'specific_category_name', '' ) );
	$data['specific_category_num']  = (int) get_theme_mod( 'specific_category_num', 0 );
	$data['display_latest_post']    = get_theme_mod( 'display_latest_post', 'yes' );

	return $data;
}
