<?php

/**
 * Header settings
 *
 * @subpackage kanagata
 * @version    1.0.0
 * @since      1.0.0
 */

/**
 * Load stylesheet
 *
 * @since 1.0
 */
function kanagata_load_stylesheets() {
	wp_enqueue_style(
		'font-awesome-woff2',
		KANAGATA_ASSETS_CSS_URL . '/libs/fonts/fontawesome-webfont.woff2',
		false,
		'4.3.0',
		'all'
	);
	wp_enqueue_style(
		'font-awesome-woff',
		KANAGATA_ASSETS_CSS_URL . '/libs/fonts/fontawesome-webfont.woff',
		false,
		'4.3.0',
		'all'
	);
	wp_enqueue_style(
		'font-awesome',
		KANAGATA_ASSETS_CSS_URL . '/libs/font-awesome/font-awesome.min.css',
		false,
		'4.3.0',
		'all'
	);
	wp_enqueue_style(
		'bootstrap',
		KANAGATA_ASSETS_CSS_URL . '/libs/bootstrap/bootstrap.min.css',
		false,
		'3.3.4',
		'all'
	);
	$slide = get_theme_mod( 'slide_header_image' );
	if ( 'yes' === $slide ) {
		wp_enqueue_style(
			'jquery.bxslider',
			KANAGATA_ASSETS_CSS_URL . '/libs/jquery.bxslider/jquery.bxslider.css',
			false,
			'4.1.2',
			'all'
		);
	}
	wp_enqueue_style(
		'lightbox',
		KANAGATA_ASSETS_CSS_URL . '/libs/lightbox/lightbox.css',
		false,
		'2.8.1',
		'all'
	);
    wp_enqueue_style( 'style', get_stylesheet_uri(), false, '3.0.0', 'screen' );
}

add_action( 'wp_enqueue_scripts', 'kanagata_load_stylesheets' );

add_filter('style_loader_tag', function($html, $handle) {
	if ($handle === 'font-awesome-woff2') {
		$html =  str_replace("rel='stylesheet'",
						   "rel='preload' as='font' type='font/woff2' crossorigin", $html);
		$html = str_replace( "type='text/css'", "", $html);
		return str_replace("media='all'", '', $html);
		
	}
	if ($handle === 'font-awesome-woff') {
		$html = str_replace("rel='stylesheet'",
						   "rel='preload' as='font' type='font/woff' crossorigin", $html);
		$html =  str_replace( "type='text/css'", "", $html);
		return str_replace("media='all'", '', $html);
	}
	return $html;
}, 10, 2);

/**
 * Load script
 *
 * @since 1.0
 */
function kanagata_load_scripts() {
	wp_enqueue_script( 'jquery' );
	if ( is_singular() ) {
		wp_enqueue_script( 'comment-reply' );
	}
	$slide = get_theme_mod( 'slide_header_image' );
	if ( 'yes' === $slide ) {
		wp_enqueue_script(
			'jquery.bxslider',
			KANAGATA_ASSETS_JS_URL . '/libs/jquery.bxslider.js',
			array(),
			'4.1.2',
			false
		);
	}
	wp_enqueue_script(
		'lightbox',
		KANAGATA_ASSETS_JS_URL . '/libs/lightbox.js',
		array(),
		'2.8.1',
		true
	);
	wp_enqueue_script(
		'sp_menu',
		KANAGATA_ASSETS_JS_URL . '/sp_menu.js',
		array( 'jquery' ),
		'1.0.0'
	);
	wp_enqueue_script(
		'app',
		KANAGATA_ASSETS_JS_URL . '/app.js',
		array( 'jquery' ),
		'1.0.0'
	);
	$slide = get_theme_mod( 'slide_header_image' );
	if ( 'yes' === $slide && true === is_front_page() ) {
		wp_enqueue_script(
			'front_slider',
			KANAGATA_ASSETS_JS_URL . '/front_slider.js',
			array( 'jquery' ),
			'1.0.0'
		);
	}

	do_action( 'kanagata_load_additional_scripts' );
}

add_action( 'wp_enqueue_scripts', 'kanagata_load_scripts' );

/**
 * Add viewport in head
 *
 * @since 1.0
 */
function kanagata_viewport() {
	$output = "\n" . '<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1" />' . PHP_EOL;
	echo $output;
}

add_action( 'wp_head', 'kanagata_viewport' );
