<?php
/**
 * Theme Initialization
 *
 * @subpackage kanagata
 * @since      1.0.0
 * @version    1.0.0
 */

/**
 * Load text domain
 */
add_action(
	'after_setup_theme',
	function () {
		load_theme_textdomain( 'kanagata', sprintf( '%s/%s', get_template_directory(), 'languages' ) );
	}
);

/**
 * Define constant variable
 *
 * @since 1.0.0
 */
add_action(
	'after_setup_theme',
	function () {
		define( 'KANAGATA_URL', esc_url( get_template_directory_uri() ) );
		define( 'KANAGATA_ASSETS_URL', KANAGATA_URL );
		define( 'KANAGATA_ASSETS_JS_URL', KANAGATA_ASSETS_URL . '/js' );
		define( 'KANAGATA_ASSETS_CSS_URL', KANAGATA_ASSETS_URL . '/css' );
	}
);

/**
 * Execute theme support
 *
 * @since 1.0.0
 */
add_action(
	'after_setup_theme',
	function () {
		/* auto feed */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		/* menu */
		register_nav_menu( 'global', __( 'Global Menu', 'kanagata' ) );
		register_nav_menu( 'extra', __( 'Extra Menu', 'kanagata' ) );
		register_nav_menu( 'side', __( 'Side Menu', 'kanagata' ) );
		register_nav_menu( 'footer', __( 'Footer Menu', 'kanagata' ) );
		/* post thumbnails(eye catch) */
		add_theme_support( 'post-thumbnails' );
		set_post_thumbnail_size( 200, 150 );
		add_image_size( 'logo', 160, 160 );
		add_theme_support(
			'custom-logo',
			array(
				'height'      => 160,
				'width'       => 160,
				'flex-height' => true,
				'flex-width'  => true,
				'header-text' => array( 'site-title', 'site-description' ),
			)
		);
		/* custom background */
		add_theme_support(
			'custom-background',
			array(
				'default-color' => 'ffffff',
				'default-image' => '',
			)
		);
		/* editor style */
		add_theme_support( 'editor-styles' );
		add_editor_style( 'style.css' );
		/* Singular page excerpt */
		add_post_type_support( 'page', 'excerpt' );
		/* custom header */
		add_theme_support(
			'custom-header',
			array(
				'width'               => 1140,
				'height'              => 330,
				'header-text'         => false,
				'default-text-color'  => '303030',
				'default-image'       => '',
				'random-default'      => false,
				'wp-head-callback'    => function () {
					$header_image = get_header_image();
					if ( empty( $header_image ) ) {
						return;
					}
					?>
			<style type="text/css">
				#header-wrap {
					background: url(<?php header_image(); ?>) no-repeat center;
				}
			</style>
					<?php
				},
				'admin-head-callback' => function () {
					?>
			<style type="text/css">
				#headimg {
					width: 1100px;
					height: 330px;
					background: no-repeat;
				}
			</style>
					<?php
				},
			)
		);
	}
);

/**
 * Register widget
 *
 * @since 1.0.0
 */
add_action(
	'widgets_init',
	function () {
		$widgets = array(
			'common' => array(
				'name'          => __( 'Common', 'kanagata' ),
				'description'   => __(
					'This is the sidebar to display on all page.',
					'kanagata'
				),
				'id'            => 'common',
				'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
				'after_widget'  => '</div></div>',
				'before_title'  => '<h4 class="title">',
				'after_title'   => '</h4>',
			),
			'home'   => array(
				'name'          => __( 'Home', 'kanagata' ),
				'description'   => __( 'Top Content on the home page', 'kanagata' ),
				'id'            => 'home',
				'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
				'after_widget'  => '</div></div>',
				'before_title'  => '<h4 class="title">',
				'after_title'   => '</h4>',
			),
			'sub'    => array(
				'name'          => __( 'Sub', 'kanagata' ),
				'description'   => __(
					'This is the sidebar to display on all page except for the top page.',
					'kanagata'
				),
				'id'            => 'sidebar',
				'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
				'after_widget'  => '</div></div>',
				'before_title'  => '<h4 class="title">',
				'after_title'   => '</h4>',
            ),
            'woocommerce'    => array(
				'name'          => __( 'WooCommerce', 'kanagata' ),
				'description'   => __(
					'This is the sidebar to display on all page except for the top page.',
					'kanagata'
				),
				'id'            => 'woocommerce',
				'before_widget' => '<div id="%1$s" class="widget %2$s"><div class="widget-inner">',
				'after_widget'  => '</div></div>',
				'before_title'  => '<h4 class="title">',
				'after_title'   => '</h4>',
            ),
        );
		foreach ( $widgets as $widget ) {
			register_sidebar( $widget );
		}
	}
);

/**
 * Load theme custom core files.
 */
add_action(
	'after_setup_theme',
	function () {
		include_once get_template_directory() . '/inc/kanagata-header.php';
		include_once get_template_directory() . '/inc/kanagata-customize-css.php';
		include_once get_template_directory() . '/inc/kanagata-customize-sanitize.php';
		include_once get_template_directory() . '/inc/kanagata-customize.php';
		include_once get_template_directory() . '/inc/kanagata-customize-functions.php';
		include_once get_template_directory() . '/inc/kanagata-block.php';
		include_once get_template_directory() . '/inc/kanagata-woocommerce.php';
	}
);
